/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jackrabbit.jcr2spi.state;

import org.apache.jackrabbit.jcr2spi.operation.Operation;

import javax.jcr.RepositoryException;

/**
 * An <code>ItemStateManager</code> that deals with state modifications.
 */
public interface UpdatableItemStateManager {

    /**
     * Executes the given operation and modifies the affected item states accordingly.
     *
     * @param operation
     * @throws RepositoryException
     */
    public void execute(Operation operation) throws RepositoryException;

    /**
     * Executes the operations passed with the given change log and modifies the
     * affected item states accordingly.
     *
     * @param changes
     * @throws RepositoryException
     */
    public void execute(ChangeLog changes) throws RepositoryException;

    /**
     * Disposes this <code>UpdatableItemStateManager</code> and frees resources.
     */
    void dispose();
}
